@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020 Alice Mikhaylenko <alicem@gnome.org>
+ * Copyright (C) 2020 Alexander Mikhaylenko <alexm@gnome.org>
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
  */
@@ -332,7 +332,7 @@ adw_carousel_indicator_dots_class_init (AdwCarouselIndicatorDotsClass *klass)
   widget_class->snapshot = adw_carousel_indicator_dots_snapshot;
 
   /**
-   * AdwCarouselIndicatorDots:carousel:
+   * AdwCarouselIndicatorDots:carousel: (attributes org.gtk.Property.get=adw_carousel_indicator_dots_get_carousel org.gtk.Property.set=adw_carousel_indicator_dots_set_carousel)
    *
    * The displayed carousel.
    */
@@ -359,8 +359,6 @@ adw_carousel_indicator_dots_init (AdwCarouselIndicatorDots *self)
 
   self->animation =
     adw_timed_animation_new (GTK_WIDGET (self), 0, 1, 0, target);
-
-  adw_timed_animation_set_easing (ADW_TIMED_ANIMATION (self->animation), ADW_LINEAR);
 }
 
 /**
@@ -377,7 +375,7 @@ adw_carousel_indicator_dots_new (void)
 }
 
 /**
- * adw_carousel_indicator_dots_get_carousel:
+ * adw_carousel_indicator_dots_get_carousel: (attributes org.gtk.Method.get_property=carousel)
  * @self: an indicator
  *
  * Gets the displayed carousel.
@@ -393,7 +391,7 @@ adw_carousel_indicator_dots_get_carousel (AdwCarouselIndicatorDots *self)
 }
 
 /**
- * adw_carousel_indicator_dots_set_carousel:
+ * adw_carousel_indicator_dots_set_carousel: (attributes org.gtk.Method.set_property=carousel)
  * @self: an indicator
  * @carousel: (nullable): a carousel
  *
